nsi.granulate.GranularUtils.Grain

Package nsi :: Package granulate :: Module GranularUtils :: Class Grain |
[hide private]
[frames] | no frames]

# Class Grain

source code

This Class is used as reference to manipulate Grains

Instance Methods | [hide private]
__init__(self, id=None, caption=None, content=None) The default attributes represent the metadata from Grain. | source code
__call__(self) Should be used getContent instead of __call___ For this object, call is useless. | source code
getId(self) | source code
setId(self, id=None) | source code
getCaption(self) | source code
setCaption(self, caption=None) | source code
getContent(self) Content is usually a StringIO. | source code
setContent(self, content=None) Content should receive only a StringIO | source code